
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: C_CVar, FPS_ABBR, GRAPHICS_LABEL, MAXFPS, MAXFPSBK, MOVIE_RECORDING_FRAMERATE, Settings, TARGETFPS, VERTICAL_SYNC, VIDEO_OPTIONS_DISABLED, VIDEO_OPTIONS_ENABLED

local floor = floor
local format = format
local GetFramerate = GetFramerate

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(SixUI) -- AddOn, Border, Constants, Database
local M = A:NewModule("Display Framerate")
local O = LibStub("LibDataBroker-1.1"):NewDataObject("SixUI Framerate", {
	type = "data source",
	text = format("%s %s", 0, FPS_ABBR),
	value = "0",
	suffix = FPS_ABBR,
	label = "Framerate",
})
local Tooltip = LibStub("SixTooltip-1.0"):CreateTooltip({
	columnJustification = {"LEFT", "LEFT"},
	font = C.TEXT_REGULAR,
	headerFont = C.TEXT_LARGE,
	key = "SixUI Framerate",
	numColumns = 2,
	separatorHeight = C.TOOLTIP_SEPARATOR_HEIGHT,
})

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnEnable()
	self:ScheduleRepeatingTimer("Update", 1)
end

function M:Update()
	local framerate = floor(GetFramerate())

	O.text = format("%s %s", framerate, O.suffix)
	O.value = framerate
end

-------------------------------------------------------------------------------
-- DataObject
-------------------------------------------------------------------------------

function O.OnEnter(frame)
	if frame then
		Tooltip:UpdateConfig({anchor = frame})
	end

	Tooltip:Show()
end

function O.OnClick(frame, button)
	if not M.GRAPHICS_CATEGORY_ID then
		M.GRAPHICS_CATEGORY_ID = A.GetSettingsCategoryID(GRAPHICS_LABEL)
	end

	Settings.OpenToCategory(M.GRAPHICS_CATEGORY_ID)
end

-------------------------------------------------------------------------------
-- Tooltip
-------------------------------------------------------------------------------

function Tooltip:OnShow()
	local gxVSync = C_CVar.GetCVarBool("gxVSync")
	local maxFPS, useMaxFPS = C_CVar.GetCVar("maxFPS"), C_CVar.GetCVarBool("useMaxFPS")
	local maxFPSBk, useMaxFPSBk = C_CVar.GetCVar("maxFPSBk"), C_CVar.GetCVarBool("useMaxFPSBk")
	local targetFPS, useTargetFPS = C_CVar.GetCVar("targetFPS"), C_CVar.GetCVarBool("useTargetFPS")

	self:AddHeader(MOVIE_RECORDING_FRAMERATE)
	self:AddSeparator(C.TOOLTIP_SEPARATOR_HEIGHT)
	self:AddLine(VERTICAL_SYNC, gxVSync and VIDEO_OPTIONS_ENABLED or VIDEO_OPTIONS_DISABLED)
	self:AddLine(MAXFPS, useMaxFPS and (maxFPS .. " " .. FPS_ABBR) or VIDEO_OPTIONS_DISABLED)
	self:AddLine(MAXFPSBK, useMaxFPSBk and (maxFPSBk .. " " .. FPS_ABBR) or VIDEO_OPTIONS_DISABLED)
	self:AddLine(TARGETFPS, useTargetFPS and (targetFPS .. " " .. FPS_ABBR) or VIDEO_OPTIONS_DISABLED)
end
